#[repr(transparent)]pub struct Sidebar {
inner: TypedObjectRef<Sidebar, <Sidebar as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
The sidebar of the session view, displaying the list of rooms available for the current session, among other things.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<Sidebar, <Sidebar as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl Sidebar
impl Sidebar
Sourcepub fn set_user<'a>(
&self,
value: Option<impl Borrow<<<RefCell<Option<User>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_user<'a>( &self, value: Option<impl Borrow<<<RefCell<Option<User>> as Property>::Value as HasParamSpec>::SetValue>>, )
The logged-in user.
Sourcepub fn list_model(&self) -> <WeakRef<SidebarListModel> as Property>::Value
pub fn list_model(&self) -> <WeakRef<SidebarListModel> as Property>::Value
The list model of this sidebar.
Sourcepub fn set_list_model<'a>(
&self,
value: Option<impl Borrow<<<WeakRef<SidebarListModel> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_list_model<'a>( &self, value: Option<impl Borrow<<<WeakRef<SidebarListModel> as Property>::Value as HasParamSpec>::SetValue>>, )
The list model of this sidebar.
Sourcepub fn connect_user_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_user_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the user property
Sourcepub fn connect_list_model_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_list_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the list-model property
Sourcepub fn notify_user(&self)
pub fn notify_user(&self)
Notify listeners of a change in the user property
Sourcepub fn notify_list_model(&self)
pub fn notify_list_model(&self)
Notify listeners of a change in the list-model property
Sourceimpl Sidebar
impl Sidebar
pub fn new() -> Self
Sourcepub(crate) fn room_search_bar(&self) -> SearchBar
pub(crate) fn room_search_bar(&self) -> SearchBar
The search bar allowing to filter rooms in the sidebar.
Sourcefn drop_source_category(&self) -> Option<RoomCategory>
fn drop_source_category(&self) -> Option<RoomCategory>
The category of the source that activated drop mode.
Sourcefn set_drop_source_category(&self, source_category: Option<RoomCategory>)
fn set_drop_source_category(&self, source_category: Option<RoomCategory>)
Set the category of the source that activated drop mode.
Sourcefn drop_active_target_category(&self) -> Option<TargetRoomCategory>
fn drop_active_target_category(&self) -> Option<TargetRoomCategory>
The category of the drop target that is currently hovered.
Sourcefn set_drop_active_target_category(
&self,
target_category: Option<TargetRoomCategory>,
)
fn set_drop_active_target_category( &self, target_category: Option<TargetRoomCategory>, )
Set the category of the drop target that is currently hovered.
Sourcefn room_row_popover(&self) -> &PopoverMenu
fn room_row_popover(&self) -> &PopoverMenu
The shared popover for a room row in the sidebar.
Sourcepub(crate) fn header_bar(&self) -> &HeaderBar
pub(crate) fn header_bar(&self) -> &HeaderBar
The AdwHeaderBar of the sidebar.
Sourcepub(crate) fn scroll_to_selection(&self)
pub(crate) fn scroll_to_selection(&self)
Scroll to the currently selected item of the sidebar.
Sourcepub fn connect_drop_source_category_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_drop_source_category_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when the drop source category changed.
Sourcepub fn connect_drop_active_target_category_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_drop_active_target_category_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when the drop active target category changed.